@@ -1,4 +1,4 @@
-from typing import Optional
+from typing import Optional, Dict
 
 
 class CdkToolConfig:
@@ -10,7 +10,8 @@ class CdkToolConfig:
             self,
             cdk_app_path: str,
             destroy_before_preparing: bool = True,
-            project_root_path: Optional[str] = None
+            project_root_path: Optional[str] = None,
+            deployment_process_environment: Optional[Dict[str, str]] = None
     ) -> None:
         """
         Constructor.
@@ -21,10 +22,13 @@ class CdkToolConfig:
         resource leftovers from a previous run.
         :param project_root_path: An absolute path to the root of your whole project. This variable is used
         to add to python path. If you face any import errors - it might be a good idea to set this variable.
+        :param deployment_process_environment: A dictionary that represent OS-level environment. This environment
+        will be passed to a process that deploys/destroys the CDK infrastructure.
         """
         self.__cdk_app_path = cdk_app_path
         self.__destroy_before_preparing = destroy_before_preparing
         self.__project_root_path = project_root_path
+        self.__deployment_process_environment = deployment_process_environment or {}
 
     @property
     def cdk_app_path(self):
@@ -37,3 +41,7 @@ class CdkToolConfig:
     @property
     def project_root_path(self):
         return self.__project_root_path
+
+    @property
+    def deployment_process_environment(self):
+        return self.__deployment_process_environment
